import getpass
import json
import click

from github import Github


def setup_github(username, password, token, config):
    """
    setup github object given credentials

    Arguments
    ---------
    username : string
        github username

    password : string
        github password

    token : string
        token generated by user on github.com

    config : string
        filename to load credentials

    Returns
    -------
    Github instance : Github
        configured connection to github
    """
    if(config):
        config = json.load(open(config, "r"))
        # we need either token
        token = config.get('token', None)

        # or username and password
        username = config.get('username', None)
        password = config.get('password', None)
    if(token):
        return Github(token, per_page=100)
    else:
        username = click.prompt('username', type=str)
        password = password if password else getpass.getpass("password: ")
        return Github(username, password, per_page=100)
